@@ -11,11 +11,11 @@ WG::API - Module for work with Wargaming.net Public API
 
 =head1 VERSION
 
-Version v0.8.7
+Version v0.8.8
 
 =cut
 
-our $VERSION = 'v0.8.7';
+our $VERSION = 'v0.8.8';
 
 =head1 SYNOPSIS
 
@@ -186,7 +186,7 @@ L<http://cpanratings.perl.org/d/WG-API>
 
 =item * Search CPAN
 
-L<http://search.cpan.org/dist/WG-API/>
+L<https://metacpan.org/pod/WG::API>
 
 =back
 
